<?php
// set application defaults
$defaults='INCLUDEFOLDER;IMAGEFOLDER;DATAFOLDER;CLIENTFOLDER;TITLE;';

$inifile='autodirector.ini';
$ini=parse_ini_file($inifile);
foreach ($ini as $key=>$value) {
	define($key, $value);
	$defaults=str_replace($key.';', '', $defaults);
}
unset($ini);

// missing application defaults
if ($defaults!='') {
	print "The following parameters are missing from the $inifile file:\n $defaults";
	exit;
}
unset($defaults);


// ________________________________________________________
// MAIN APPLICATION

// PHP includes
require(INCLUDEFOLDER.'dbhandler.php');
require(INCLUDEFOLDER.'aduser.php');
require(INCLUDEFOLDER.'adsite.php');
require(INCLUDEFOLDER.'adfunctions.php');

// set defaults
define('USERID', readCookie('aduserid'));
$setsite=getvar('siteid');
if ($setsite=='') define('SITEID', readCookie('adsiteid'));
else {
	// new site defined
	define ('SITEID', $setsite);
	writeCookie('adsiteid', SITEID);
}
define('THISURL', $_SERVER['PHP_SELF']);
define('FULLURL', scriptPath());

// setup database object
$db=new dbObject;

// find out user information
$thisUser=new userObject;
$thisUser->selectDB($db);

// no user ID defined - return to login
if (USERID=='') {
	header('Location: '.FULLURL.'index.php');
	exit();
}
else {
	if (!$thisUser->fetchUser(USERID)) {
		print '<html><head><title>AutoDirector</title></head><body><p>The user account '.USERID.' is not defined, or a database communication error has occurred. Please <a href="index.php">log in again</a> or contact your administrator.</p></body></html>';
		exit();
	}
}

// page header
$pagetitle=SITEID.' integration options';
require(INCLUDEFOLDER.'adpagehead.php');
showMenu('integration');

// JavaScript includes
print '<script type="text/javascript" src="'.INCLUDEFOLDER.'adscript.js"></script>';

// JavaScript setup
print "<script type=\"text/javascript\">\n";
print "run+=\"startup();\";\n";
print "function startup() { form=document.autodirector; }\n";
print "function gopage(pagename) { if (loaded) { form.page.value=pagename; form.submit(); } }\n";
print "</script>\n";

// set page value
$page=postvar('page', '');
$style=postvar('style', '');

// set up site object
$thisSite=new siteObject();
$thisSite->selectDB($db);
if (!$thisSite->fetchSite(SITEID)) $page='notavailable';

// delete log
$resetlog=NULL;
if ($page=='resetlog') {
	$resetlog=@unlink(DATAFOLDER.SITEID.'/enquiries.txt');
	$page='';
}

// start form
print '<form name="autodirector" action="'.THISURL.'" method="post">';
doHidden('page');

// show main menu
showMain($page=='');

// other pages
showBasic($page=='basic');
showStylesBasic($page=='stylesbasic');
showStyles($page=='stylesheets');
linkIDs($page=='linkids');
setPageSize($page=='pagesizes');
showSearch($page=='searchform');

// no permission page
notAvailable($page=='notavailable');

// end form
print '</form>';

// disconnect from database
$db->dbDisconnect();
unset($db);

// unload variables
unset($thisUser);

// page footer
require(INCLUDEFOLDER.'adpagefoot.php');


// ________________________________________________________
// show main menu options
function showMain($show=true) {

	global $thisSite, $thisUser, $resetlog;

	if ($show) {

		print '<p>The following instructions will help you show your vehicle list on your website.</p><h2>basic integration</h2><ul><li><a href="javascript:gopage(\'basic\');">basic integration instructions</a><br />the minimum code required to show your vehicles on your website.</li><li><a href="javascript:gopage(\'stylesbasic\');">simple style changes</a><br />how to make simple style changes to an existing template.</li></ul>';

		print '<h2>advanced integration</h2><p>The following options show how you can customise your vehicle list:</p><ul>';
		print '<li><a href="javascript:gopage(\'pagesizes\');">set the page sizes</a><br />set the number of vehicles shown per page.</li>';
		print '<li><a href="javascript:gopage(\'stylesheets\');">using your own styles</a><br />how to create your own stylesheet and match your site\'s fonts, colours and styling.</li>';
		print '<li><a href="javascript:gopage(\'linkids\');">promote an individual vehicle</a><br />how to link to your vehicle list page and show a specific vehicle.</li>';
		if ($thisSite->searchon) print '<li><a href="javascript:gopage(\'searchform\');">create your own search form</a><br />provide your customers with a vehicle search box on any page of your website.</li>';
		print '</ul>';

		if ($thisUser->permissionLevel($thisSite->siteid)>=2) {
			print '<h2>enquiry log</h2><p>All vehicle enquiries are saved to a log:</p><ul>';
			print '<li><a href="enquirylog.php?site='.$thisSite->siteid.'" target="enquiries">view your enquiry log</a><br />show all enquiries since your last reset.</li>';
			print '<li><a href="javascript:if (window.confirm(\'Are you sure you want to\ndelete your enquiry log?\')) gopage(\'resetlog\');">reset your enquiry log</a><br />delete all entries in your enquiry log.';
			if ($resetlog) print '<br /><b>Your enquiry log has been reset.</b>';
			print '</li></ul>';
		}
	}
}


// ________________________________________________________
// show basic integration options
function showBasic($show=true) {

	global $thisSite;

	if ($show) {

		$url=scriptPath().'carlist.php';
		print '<p>To display your vehicles on your site, the following code must be cut and pasted into your page:</p><pre>&lt;div id="autodirector"&gt;&lt;/div&gt;<br />&lt;script type="text/javascript" src="'.scriptPath().'carlist.php?site='.$thisSite->siteid.'&amp;amp;style=<b><i>ChosenStyle</i></b>"&gt;&lt;/script&gt;</pre>';
		print '<p>where <b><i>ChosenStyle</i></b> can be set to:</p><table align="center" border="0" cellpadding="4" cellspacing="0">';

		// fetch all styles
		$styles=getStyles();
		for ($i=0; $i<count($styles); $i++) print "<tr><td><b>$styles[$i]</b></td><td><a href=\"example.php?site=$thisSite->siteid&style=$styles[$i]\" target=\"adexample\"><i>view example...</i></a></td></tr>";
		print '</table><br clear="all" />';

		print '<p><b>Notes:</b></p><ul>';
		print '<li>the &lt;div id="autodirector"&gt;&lt;/div&gt; must always appear in the HTML page &lt;body&gt;. The showroom will appear at that location.</li>';
		print '<li>the &lt;script ...&gt; tag can go anywhere in your page, e.g. within the HTML &lt;head&gt; or immediately before the &lt;/body&gt;</li>';
		if ($thisSite->searchon) print '<li>a search box will only appear on your showroom once you have defined ten or more vehicles.</li>';
		print "</ul>";
		
		// back to main menu
		print '<p><a href="javascript:gopage(\'\');">&lt;&nbsp;back</a></p>';
	}

}

// ________________________________________________________
// show basic style change options
function showStylesBasic($show=false) {

	global $thisSite;
	
	if ($show) {

		print '<p>If your website uses CSS (Cascading Style Sheets), your chosen <a href="javascript:gopage(\'basic\');">template</a> will use your font styles, sizes and colours.</p><p>Simple changes can be made by applying styles to the #autodirector element (or its parent element or the HTML &lt;body&gt;). For example, to set the default font to a smaller Tahoma, you could use the following CSS code in the &lt;head&gt; of your page:';
		print "<pre>&lt;style type=&quot;text/css&quot;&gt;\n/* &lt;![CDATA[ */\ndiv#autodirector\n{\n\tfont-family: tahoma;\n\tfont-size: x-small;\n}\n/* ]]&gt; */\n&lt;/style&gt;</pre>";
		print '<p>Styles can be used to change many aspects of your showroom. There are many CSS resources on the web if you require further assistance.</p>';
		
		// back to main menu
		print '<p><a href="javascript:gopage(\'\');">&lt;&nbsp;back</a></p>';
	
	}

}

// ________________________________________________________
// show stylesheet options
function showStyles($show=false) {

	global $thisSite;

	if ($show) {
		$url=scriptPath().'carlist.php';
		print '<p>The showroom uses Cascading Style Sheets (CSS) to provide flexible alternative designs. A <a href="javascript:gopage(\'basic\');">selection of stylesheets</a> is provided, but you can create your own:</p>';
		print '<pre>&lt;link rel="stylesheet" type="text/css" href="yourstylesheet.css" /&gt;<br /><br />&lt;div id="autodirector"&gt;&lt;/div&gt;<br />&lt;script type="text/javascript" src="'.scriptPath().'carlist.php?site='.$thisSite->siteid.'"&gt;&lt;/script&gt;</pre>';
		print '<p>(Note that the stylesheet &lt;link&gt; tag is best placed within the &lt;head&gt; of your webpage.)</p>';
		print '<p>Create a file called <b>yourstylesheet.css</b> containing your styles. It is easiest to modify an existing stylesheet:</p><table align="center" border="0" cellpadding="4" cellspacing="0">';

		// fetch all styles
		$styles=getStyles();
		for ($i=0; $i<count($styles); $i++) print "<tr><td><b>$styles[$i]</b></td><td><a href=\"client/$styles[$i].css\"><i>download stylesheet...</i></a></td></tr>";
		print '</table><br clear="all" />';

		print '<p>The structure of the HTML code can be examined using a tool such as the <a href="http://www.spreadfirefox.com/?q=affiliates&amp;id=157&amp;t=1" target="firefox">Firefox</a> DOM inspector. The following basic element hierarchy is used:</p>';
		print '<ol class="structure"><li><b>div#autodirector</b> - outer element<ol><li><b>div#autodirector_search</b> - order by and search box<ol><li><b>form#adsearch</b> - actual form<ol><li><b>div.order</b> - order by group</li><li><b>div.search</b> - search group</li></ol></li></ol></li><li><b>div#autodirector_jumptop</b> - page view controls</li><li><b>div#autodirector_list</b> - vehicle showroom list<ol><li><b>a</b> - vehicle summary<ol><li><b>img</b> - vehicle image</li><li><b>dl</b> - vehicle description</li><li><b>div</b> - price</li></ol></li></ol></li><li><b>div#autodirector_jumpend</b> - page view controls</li><li><b>div#autodirector_backtop</b> - back to showroom link</li><li><b>div#autodirector_vehicle</b> - vehicle details<ol><li><b>ol#autodirector_pics</b> - list of vehicle images (within &lt;li&gt;, &lt;a&gt;, then &lt;img&gt; sub-nodes)</li><li><b>dl</b> - vehicle description</li><li><b>div.price</b> - price</li></ol></li><li><b>div#autodirector_enqresult</b> - enquiry status messages</li><li><b>div#autodirector_enquiry</b> - enquiry form<ol><li><b>form#adenquiry</b> - actual form</li></ol></li><li><b>div#autodirector_backend</b> - back to showroom link</li><li><b>div#autodirector_sponsor</b> - sponsorship details</li></ol></li></ol>';
		print '<p>There are many CSS resources on the web if you require further assistance.</p>';

		// back to main menu
		print '<p><a href="javascript:gopage(\'\');">&lt;&nbsp;back</a></p>';
	}

}

// ________________________________________________________
// set page sizes
function linkIDs($show=false) {

	global $thisSite;

	if ($show) {
		print '<p>The system also allows you to show a specific vehicle as well as your whole vehicle list. For example, your home page could link to one or more vehicles you wish to promote. You could also use links to individual vehicles within a newsletter sent to your customers.</p>';
		print '<p>For this example, we will assume your vehicle list is shown on the page <b>http://www.mysite.com/vehicles.html</b>. The URL you should use for an individual vehicle is therefore:</p>';
		print '<pre>http://www.mysite.com/vehicles.html?cid=<b>N</b></pre>';
		print '<p>where <b>N</b> is the ID number of the vehicle you want to promote.</p>';
		print '<p>Vehicle IDs can be found on the <a href="vehicleadmin.php?siteid='.$thisSite->siteid.'">vehicle administration</a> screen. Click the <b>edit</b> link next the appropriate vehicle and scroll to the bottom-right of the page. You will see:</p><p style="color:#999999;text-align:center;">( Vehicle ID: <b>N</b> )</p><p>Note the ID number and use it in your link.</p>';

		// back to main menu
		print '<p><a href="javascript:gopage(\'\');">&lt;&nbsp;back</a></p>';
	}
}

// ________________________________________________________
// set page sizes
function setPageSize($show=false) {

	global $thisSite;

	if ($show) {
		print '<p>Your visitors can choose whether to display 5, 10, 25, 50 or all vehicles per page. These page sizes can be changed by adding a <b>pagesizes</b> argument to the script link. For example, to set page sizes of 2, 8 and 16, use:</p>';
		print '<pre>&lt;div id="autodirector"&gt;&lt;/div&gt;<br />&lt;script type="text/javascript" <br />src="'.scriptPath().'carlist.php?site='.$thisSite->siteid.'&amp;amp;style=<i>ChosenStyle</i>&amp;amp;<b>pagesizes=2,8,16</b>"&gt;&lt;/script&gt;</pre>';
		print '<p>Note that using a page size of 0 (zero) will show the \'all\' vehicles option.</p>';

		// back to main menu
		print '<p><a href="javascript:gopage(\'\');">&lt;&nbsp;back</a></p>';
	}
}


// ________________________________________________________
// how to implement a search form
function showSearch($show=false) {

	global $thisSite;

	if ($show) {
		print '<p>Once you have a working vehicle list, you can implement a vehicle search box on any web page.</p><p>For this example, we will assume your vehicle list is shown on the page <b>http://www.mysite.com/vehicles.html</b>. To create a vehicle search form to another page, use code such as:</p>';
		print '<pre>&lt;form action="http://www.mysite.com/vehicles.html" method="get"&gt;<br />&lt;label&gt;search: &lt;input type="text" name="search" size="12" maxlength="30" /&gt;&lt;/label&gt;<br />&lt;input type="submit" value="go" /&gt;<br />&lt;/form&gt;</pre>';
		print '<p>This HTML can be modified if necessary. CSS can be used to style the form and JavaScript could provide validation.</p>';
		// back to main menu
		print '<p><a href="javascript:gopage(\'\');">&lt;&nbsp;back</a></p>';
	}
}


// ________________________________________________________
// show that user does not have the appropriate permissions
function notAvailable($show=false) {
	if ($show) {
		print '<p class="error">Integration options are not available. Please contact your administrator.</p>';
		print '<p>Site ID: '.SITEID.'</p>';
	}
}


// ________________________________________________________
// fetch list of styles
function getStyles() {
	if ($dir=opendir(CLIENTFOLDER)) {
		while (($file=readdir($dir)) !== false) {
			if (strpos(strtolower($file), '.css') !== false) $styles[]=substr($file, 0, strlen($file)-4);
		}
		closedir($dir);
	}
	sort($styles);
	return $styles;
}
?>