<?php
// set application defaults
$defaults='INCLUDEFOLDER;IMAGEFOLDER;DATAFOLDER;UPLOADSIZELIMIT;UPLOADTIMELIMIT;TITLE;';

$inifile='autodirector.ini';
$ini=parse_ini_file($inifile);
foreach ($ini as $key=>$value) {
	define($key, $value);
	$defaults=str_replace($key.';', '', $defaults);
}
unset($ini);

// missing application defaults
if ($defaults!='') {
	print "The following parameters are missing from the $inifile file:\n $defaults";
	exit;
}
unset($defaults);

// set maximum execution time and file upload limit
@ini_set('file_uploads', '1');
define('IMAGEUPLOAD', (extension_loaded('gd') && ini_get('file_uploads')));
if (IMAGEUPLOAD) {
	@ini_set('post_max_size', UPLOADSIZELIMIT);
	@ini_set('upload_max_filesize', UPLOADSIZELIMIT);
	@set_time_limit(UPLOADTIMELIMIT);
}


// ________________________________________________________
// MAIN APPLICATION

// PHP includes
require(INCLUDEFOLDER.'dbhandler.php');
require(INCLUDEFOLDER.'aduser.php');
require(INCLUDEFOLDER.'adsite.php');
require(INCLUDEFOLDER.'advehicle.php');
require(INCLUDEFOLDER.'adfunctions.php');
require(INCLUDEFOLDER.'adgraphicfunctions.php');

// set defaults
define('USERID', readCookie('aduserid'));
$cleanup=false;
$setsite=getvar('siteid');
if ($setsite=='') define('SITEID', readCookie('adsiteid'));
else {
	// new site defined
	define ('SITEID', $setsite);
	writeCookie('adsiteid', SITEID);
	// clean up (1 in 10 chance)
	if (rand(1,10)>9) $cleanup=true;
}
define('SITEDATA',DATAFOLDER.SITEID.'/');
define('PICFOLDER',SITEDATA.'pics/');
define('THUMBFOLDER',SITEDATA.'thumbs/');
define('SITELOG',SITEDATA.'log.txt');
define('THISURL', $_SERVER['PHP_SELF']);
define('FULLURL', scriptPath());

// setup database object
$db=new dbObject;

// run clean up operation
if ($cleanup) {
	// fetch picture filenames from database
	$validpics='';
	if ($db->fetch("SELECT picturelist FROM ".SITEID." WHERE picturelist!='';")) {
		$validpics=',';
		while ($row=$db->row()) {
			$validpics.=$row[0].',';
		}
		// delete unnecessary pictures
		cleanPics(PICFOLDER, $validpics, SITELOG);
		cleanPics(THUMBFOLDER, $validpics, SITELOG);
	}
}

// find out user information
$thisUser=new userObject;
$thisUser->selectDB($db);

// no user ID defined - return to login
if (USERID=='') {
	header('Location: '.FULLURL.'index.php');
	exit();
}
else {
	if (!$thisUser->fetchUser(USERID)) {
		print '<html><head><title>AutoDirector</title></head><body><p>The user account '.USERID.' is not defined, or a database communication error has occurred. Please <a href="index.php">log in again</a> or contact your administrator.</p></body></html>';
		exit();
	}
}

// find out site information
$thisSite=new siteObject;
$thisSite->selectDB($db);

if (!$thisSite->fetchSite(SITEID)) {
	print '<p>The site '.SITEID.' is not defined, or a database communication error has occurred. Processing cannot continue - please contact your administrator.</p>';
	exit();
}

// page header
$pagetitle=SITEID.' vehicle administration';
require(INCLUDEFOLDER.'adpagehead.php');

// JavaScript includes
print '<script type="text/javascript" src="'.INCLUDEFOLDER.'adscript.js"></script>';
print '<script type="text/javascript" src="'.INCLUDEFOLDER.'adscriptvehicle.js"></script>';

// JavaScript setup
print "<script type=\"text/javascript\">\n";
print "run+=\"startup();\";\n";
print "var pics=\"\";\n";
print "var thumbs=\"\";\n";
print "function startup() { form=document.autodirector; pics=\"".PICFOLDER."\"; thumbs=\"".THUMBFOLDER."\"; picdim=\"".$thisSite->picdimension."\"; cursymbol=\"".$thisSite->cursymbol."\"; }\n";
print "</script>\n";

// set page value
$page=postvar('page', '');

// check if user authorised for this site
if ($thisUser->permissionLevel(SITEID)<3 && $thisSite->blockvehicleadmin) $page='nopermission';

// editing
$editrecord=intval(postvar('editrecord', 0));

// picture upload
if ($page=='picupload') {
	fetchVehicleForm();
	$operation=$page;
	$result=uploadPictures();
	$page='edit';
}

// picture delete
if ($page=='picdelete') {
	fetchVehicleForm();
	$operation=$page;
	deletePictures(false);
	$page='edit';
}

// cancel editing
if ($page=='canceledit') {
	fetchVehicleForm();
	if ($picsadded!='') {
		$picdeleteall=$picsadded;
		deletePictures(true);
	}
	$page='';
}

// update record
if ($page=='update') {
	fetchVehicleForm();
	deletePictures(true);
	$operation=$page;
	$result=updateRecord();
	$result.=generateFiles($thisSite, FULLURL, DATAFOLDER);
	$page='';
}

// delete records
if ($page=='delete') {
	$operation='delete';
	$result=deleteRecords();
	$result.=generateFiles($thisSite, FULLURL, DATAFOLDER);
	$page='';
}

// show menu
if ($page=='edit') showMenu('vehicleedit'); else showMenu('vehiclelist');

// start form
print '<form name="autodirector" action="'.THISURL.'" method="post" enctype="multipart/form-data">';
doHidden('page');

// show vehicle list
showList($page=='');

// show edit page
showEdit($page=='edit');

// no permission page
showPermission($page=='nopermission');

// end form
print '</form>';

// disconnect from database
$db->dbDisconnect();
unset($db);

// unload variables
unset($thisSite);
unset($thisUser);

// page footer
require(INCLUDEFOLDER.'adpagefoot.php');


// ________________________________________________________
// shows all available vehicles
function showList($show=true) {

	global $db, $thisSite, $thisUser, $operation, $result;

	// available page sizes
	$pagesizelist=Array(10, 20, 30, 50, 100);

	$pagesize=intval(postvar('pagesize', $pagesizelist[0]));
	$pagenum=intval(postvar('pagenum', 1));
	$sortby=postvar('sortby', 'lastupdate');
	$sorttype=postvar('sorttype', 'DESC');
	$dokey=false;

	doHidden('pagenum', $pagenum);
	doHidden('sortby', $sortby);
	doHidden('sorttype', $sorttype);

	if ($show) {

		doHidden('editrecord');
		doHidden('delrecords');

		// show list of vehicles
		$db->pagesize=$pagesize;
		if ($db->fetch("SELECT id,display,year,make,model,type,regnumber,colour,price,lastupdate,userupdate,picturelist,views,enquiries FROM ".SITEID." ORDER BY $sortby $sorttype;")) {

			if ($db->rowcount==0) {
				print '<p class="error">No vehicles are currently available.</p>';
			}
			else {

				// table header
				print '<table align="center" border="0" cellpadding="2" cellspacing="1" bgcolor="#000000">';
				print '<tr><td colspan="15" class="heading">Your vehicle list</td></tr>';
				print '<tr><th class="sortby">&nbsp;</th><th class="sortby">&nbsp;</th>';
				print '<th class="sortby'.($sortby=='year').'">yr&nbsp;<a href="javascript:tablesort(\'year\',\'asc\')"><img src="'.IMAGEFOLDER.'arrowup.gif" border="0" /></a><a href="javascript:tablesort(\'year\',\'desc\')"><img src="'.IMAGEFOLDER.'arrowdn.gif" border="0" /></a></th>';
				print '<th class="sortby'.($sortby=='make').'">make&nbsp;<a href="javascript:tablesort(\'make\',\'asc\')"><img src="'.IMAGEFOLDER.'arrowup.gif" border="0" /></a><a href="javascript:tablesort(\'make\',\'desc\')"><img src="'.IMAGEFOLDER.'arrowdn.gif" border="0" /></a></th>';
				print '<th class="sortby'.($sortby=='model').'">model&nbsp;<a href="javascript:tablesort(\'model\',\'asc\')"><img src="'.IMAGEFOLDER.'arrowup.gif" border="0" /></a><a href="javascript:tablesort(\'model\',\'desc\')"><img src="'.IMAGEFOLDER.'arrowdn.gif" border="0" /></a></th>';
				print '<th class="sortby'.($sortby=='type').'">type&nbsp;<a href="javascript:tablesort(\'type\',\'asc\')"><img src="'.IMAGEFOLDER.'arrowup.gif" border="0" /></a><a href="javascript:tablesort(\'type\',\'desc\')"><img src="'.IMAGEFOLDER.'arrowdn.gif" border="0" /></a></th>';
				print '<th class="sortby'.($sortby=='regnumber').'">reg&nbsp;<a href="javascript:tablesort(\'regnumber\',\'asc\')"><img src="'.IMAGEFOLDER.'arrowup.gif" border="0" /></a><a href="javascript:tablesort(\'regnumber\',\'desc\')"><img src="'.IMAGEFOLDER.'arrowdn.gif" border="0" /></a></th>';
				print '<th class="sortby'.($sortby=='colour').'">col&nbsp;<a href="javascript:tablesort(\'colour\',\'asc\')"><img src="'.IMAGEFOLDER.'arrowup.gif" border="0" /></a><a href="javascript:tablesort(\'colour\',\'desc\')"><img src="'.IMAGEFOLDER.'arrowdn.gif" border="0" /></a></th>';
				print '<th class="sortby'.($sortby=='price').'">price&nbsp;<a href="javascript:tablesort(\'price\',\'asc\')"><img src="'.IMAGEFOLDER.'arrowup.gif" border="0" /></a><a href="javascript:tablesort(\'price\',\'desc\')"><img src="'.IMAGEFOLDER.'arrowdn.gif" border="0" /></a></th>';
				print '<th class="sortby">pics</th>';
				print '<th class="sortby'.($sortby=='lastupdate').'">modified&nbsp;<a href="javascript:tablesort(\'lastupdate\',\'asc\')"><img src="'.IMAGEFOLDER.'arrowup.gif" border="0" /></a><a href="javascript:tablesort(\'lastupdate\',\'desc\')"><img src="'.IMAGEFOLDER.'arrowdn.gif" border="0" /></a></th>';
				print '<th class="sortby'.($sortby=='userupdate').'">by&nbsp;<a href="javascript:tablesort(\'userupdate\',\'asc\')"><img src="'.IMAGEFOLDER.'arrowup.gif" border="0" /></a><a href="javascript:tablesort(\'userupdate\',\'desc\')"><img src="'.IMAGEFOLDER.'arrowdn.gif" border="0" /></a></th>';
				print '<th class="sortby'.($sortby=='views').'">vws&nbsp;<a href="javascript:tablesort(\'views\',\'asc\')"><img src="'.IMAGEFOLDER.'arrowup.gif" border="0" /></a><a href="javascript:tablesort(\'views\',\'desc\')"><img src="'.IMAGEFOLDER.'arrowdn.gif" border="0" /></a></th>';
				print '<th class="sortby'.($sortby=='enquiries').'">eqs&nbsp;<a href="javascript:tablesort(\'enquiries\',\'asc\')"><img src="'.IMAGEFOLDER.'arrowup.gif" border="0" /></a><a href="javascript:tablesort(\'enquiries\',\'desc\')"><img src="'.IMAGEFOLDER.'arrowdn.gif" border="0" /></a></th>';
				print '<th class="sortby'.($sortby=='display').'">on&nbsp;<a href="javascript:tablesort(\'display\',\'asc\')"><img src="'.IMAGEFOLDER.'arrowup.gif" border="0" /></a><a href="javascript:tablesort(\'display\',\'desc\')"><img src="'.IMAGEFOLDER.'arrowdn.gif" border="0" /></a></th>';
				print '</tr>';

				if ($pagenum>$db->pagecount) { $pagenum=$db->pagecount; }
				$db->pagejump($pagenum);

				// retrieve all rows
				for ($i=$db->rowfrom; $i<=$db->rowto; $i++) {
					$row=$db->rowassoc();
					print "<tr><td class=\"sortby\"><a href=\"javascript:edititem('${row['id']}')\" title=\"edit ${row['year']} ${row['make']} ${row['model']} (ID ${row['id']})\" onmouseover=\"rowColour('${row['id']}','rowover')\" onmouseout=\"rowColour('${row['id']}','rowout')\" class=\"edit\">edit&nbsp;<img src=\"".IMAGEFOLDER."arrowrt.gif\" border=\"0\" align=\"absmiddle\" /></a></td>";
					print "<td class=\"sortby\"><input type=\"checkbox\" name=\"car${row['id']}\" /></td>";
					print "<td id=\"${row['id']}_1\" align=\"right\">&nbsp;${row['year']}</td>";
					print "<td id=\"${row['id']}_2\">".truncString($row['make'],8,12).'&nbsp;</td>';
					print "<td id=\"${row['id']}_3\">".truncString($row['model'],8,12).'&nbsp;</td>';
					print "<td id=\"${row['id']}_4\">".truncString($row['type'],5,10).'&nbsp;</td>';
					print "<td id=\"${row['id']}_5\">".truncString($row['regnumber'],5,10).'&nbsp;</td>';
					print "<td id=\"${row['id']}_6\">".truncString($row['colour'],5,10).'&nbsp;</td>';
					print "<td id=\"${row['id']}_7\" align=\"right\">";
					if ($row['price'] != '' && is_numeric($row['price'])) {
						if ($row['price'] <= 1) print 'call';
						else print $thisSite->curhtml.number_format($row['price']);
					}
					else print 'sold';
					print '</td>';
					print "<td id=\"${row['id']}_8\" align=\"right\">".(substr_count($row['picturelist'], ',')+(strlen($row['picturelist'])>0)).'</td>';
					print "<td id=\"${row['id']}_9\" align=\"right\">".date("d-m-y H:i", strtotime($row['lastupdate'])).'</td>';
					print "<td id=\"${row['id']}_10\">";
					if ($row['userupdate']!='') print "<a href=\"mailto:${row['userupdate']}?subject=${row['year']} ${row['make']}%20${row['model']}%20${row['type']}%20${row['regnumber']}\">".truncEmail($row['userupdate']).'</a>';
					else print '&nbsp;';
					print '</td>';
					print "<td id=\"${row['id']}_11\" align=\"right\">${row['views']}</td>";
					print "<td id=\"${row['id']}_12\" align=\"right\">${row['enquiries']}</td>";
					print "<td id=\"${row['id']}_13\" align=\"center\">";
					if ($row['display']) { print 'yes'; } else { print '<b class="error">NO</b>'; }
					print '</td></tr>';
				}

				print '<th colspan="15" class="sortby"><table width="100%" border="0" cellpadding="0" cellspacing="1"><tr>';
				print '<td class="sortby"><input type="button" value="delete selected" onclick="deleteselected()" class="button" /></td>';
				print "<td align=\"center\" class=\"sortby\"><b>Viewing vehicles $db->rowfrom to $db->rowto of $db->rowcount</b></td>";
				print '<td align="right" class="sortby">Show <select name="pagesize" onchange="if (loaded) { form.pagenum.value=1;this.form.submit(); }">';
				for ($i=0; $i<sizeof($pagesizelist); $i++) {
					print "<option value=\"$pagesizelist[$i]\"";
					if ($pagesize==$pagesizelist[$i]) { print " selected"; }
					print ">$pagesizelist[$i]</option>";
				}
				print '</select> per page</td><td align="right" class="sortby">&nbsp;';

				// back button
				if ($pagenum>1) { print '<a href="javascript:jumppage('.($pagenum-1).')"><img src="'.IMAGEFOLDER.'arrowlt.gif" border="0" alt="previous page" /></a>&nbsp;'; }

				// page drop down
				if ($db->pagecount>1) {
					print '<select name="gopage" onchange="jumppage(this.options[this.selectedIndex].value)">';
					for ($i=1; $i<=$db->pagecount; $i++) {
						print '<option ';
						if ($i==$pagenum) { print 'value="0" style="color:#666666;" selected>'; } else { print "value=\"$i\">"; }
						print "page $i</option>";
					}
					print '</select>';
				}

				// next button
				if ($pagenum<$db->pagecount) { print '&nbsp;<a href="javascript:jumppage('.($pagenum+1).')"><img src="'.IMAGEFOLDER.'arrowrt.gif" border="0" alt="next page" /></a>'; }
				print '</td></tr></table></th></table><br clear="all" />';

				$dokey=true;
			}

			// add a new vehicle
			if ($db->rowcount < $thisSite->maxentries || $thisUser->supervisor) {
				print '<div align="center"><input type="button" value="add a new vehicle" onclick="edititem(\'\')" class="button" /></div><br clear="all" /><br />';
			}
			else {
				print '<p align="center" class="error">You reached your limit of '.$thisSite->maxentries.' vehicles: no more can be added.</p>';
			}
			
			// import vehicles
			print '<p align="right"><a href="importadmin.php?siteid='.SITEID.'"><img src="'.IMAGEFOLDER.'iconimport.gif" border="0" align="top" hspace="3">vehicle import wizard</a></p>';

		}
		else {
			print '<p align="center" class="error">The database is not available. Please contact your administrator.</p>';
		}

		// operations
		if ($operation=='delete' || $operation=='update') { print "<p align=\"center\" class=\"error\">$result</p>"; }

		// show table key
		if ($dokey) print '<p><table border="0" cellpadding="2" cellspacing="0"><tr><td colspan="2"><b class="error">Key:</b></td></tr><tr><td><b>yr</b></td><td>year of manufacture</td></tr><tr><td><b>reg</b></td><td>registration number</td></tr><tr><td><b>col</b></td><td>colour of vehicle</td></tr><td><b>pics</b></td><td>number of vehicle photographs</td></tr><tr><td><b>vws</b></td><td>number of viewings</td></tr><tr><td><b>eqs</b></td><td>number of enquiries</td></tr><tr><td><b>on</b></td><td>indicates whether vehicle is displayed</td></tr></table></p>';

	}
	else {
		// list not shown
		doHidden('pagesize', $pagesize);
	}
}


// ________________________________________________________
// show edit screen
function showEdit($show=false) {

	global $db, $thisSite, $editrecord, $operation, $result;
	global $display, $new, $year, $make, $model, $type, $regnumber, $mileage, $colour, $gearbox, $info, $price, $picturelist, $picdeleteall, $picsadded;

	if ($show) {

		doHidden('editrecord', $editrecord);
		$geartypes=array('unknown', 'manual', 'automatic', 'tiptronic');

		// no current operation
		if ($operation=="") {

			// reset picture usage
			$picdeleteall="";
			$picsadded="";

			if ($editrecord==0) {

				// set vehicle defaults
				$display=true;
				$new=false;
				$year='';
				$make='';
				$model='';
				$type='';
				$regnumber='';
				$mileage='';
				$colour='';
				$gearbox='unknown';
				$info='';
				
				// fetch default info text from file
				if (file_exists('info-'.SITEID.'.txt')) $info = @file_get_contents('info-'.SITEID.'.txt');
				else if (file_exists('info.txt')) $info = @file_get_contents('info.txt');
				if (!is_string($info)) $info = '';
				
				$price='';
				$picturelist='';
			}
			else {

				// retrieve vehicle data from database
				if ($db->fetch("SELECT * FROM ".SITEID." WHERE id=$editrecord;")) {
					$car=$db->rowassoc();
					$display=$car['display'];
					$new=$car['new'];
					$year=$car['year'];
					$make=$car['make'];
					$model=$car['model'];
					$type=$car['type'];
					$regnumber=$car['regnumber'];
					$mileage=number_format($car['mileage']);
					$colour=$car['colour'];
					$gearbox=$car['gearbox'];
					$info=$car['info'];
					if ($car['price'] != '' && is_numeric($car['price'])) $price=$thisSite->curhtml.number_format($car['price']);
					$picturelist=$car['picturelist'];
				}
				else print '<p class="error">WARNING: vehicle data could not be retrieved. Please cancel and try again.</p>';
			}
		}
		else {
			if ($mileage!='') $mileage=number_format($mileage);
			if ($price!='' && is_numeric($price)) $price=$thisSite->curhtml.number_format($price);
		}

		// show edit form
		// if ($editrecord==0) { print "<p>Add a new vehicle:</p>"; } else { print "<p>Edit this vehicle:</p>"; }
		print '<table align="center" border="0" cellpadding="0" cellspacing="1">';

		print '<tr><td colspan="4" class="question"><input type="checkbox" name="display"';
		if ($display) print " checked";
		print ' />&nbsp;<a href="javascript:toggleCheckbox(\'display\')" class="field"><b>display this vehicle</b></a></td></tr>';

		print '<tr><td colspan="4" class="line">&nbsp;</td></tr>';

		print '<tr><td valign="top" class="question"><b>this vehicle is:</b></td><td colspan="3" valign="top" class="field">';
		print '<input type="radio" name="new" value="1"';
		if ($new) { print ' checked'; }
		print ' />&nbsp;<a href="javascript:selectradio(\'new\',1)" class="field">new</a><br />';
		print '<input type="radio" name="new" value="0"';
		if (!$new) { print ' checked'; }
		print ' />&nbsp;<a href="javascript:selectradio(\'new\',2)" class="field">used</a><br />';
		print '</td></tr>';

		print '<tr><td colspan="4" class="line">&nbsp;</td></tr>';

		print '<tr><td class="question"><b>year</b>, eg. '.date('Y').'&nbsp;&nbsp;</td><td class="question"><b>make</b>, eg. Ford&nbsp;&nbsp;</td><td class="question"><b>model</b>, eg. Focus&nbsp;&nbsp;</td><td class="question"><b>type</b>, eg. ZX</td></tr>';
		print '<tr><td class="field"><input type="text" name="year" value="'.$year.'" size="6" maxlength="4" onchange="this.value=format_year(this.value);" style="text-align:right;" /></td><td class="field"><input type="text" name="make" value="'.$make.'" size="20" maxlength="30" /></td><td class="field"><input type="text" name="model" value="'.$model.'" size="20" maxlength="30" /></td><td class="field"><input type="text" name="type" value="'.$type.'" size="20" maxlength="30" /></td></tr>';

		print '<tr><td colspan="4" class="line">&nbsp;</td></tr>';

		if ($thisSite->cursymbol == '$') {
			$labelgb = 'transmission';
			$labelcol = 'color';
			$labelreg = 'VIN#';
		}
		else {
			$labelgb = 'gearbox';
			$labelcol = 'colour';
			$labelreg = 'registration number';
		}

		print "<tr><td class=\"question\"><b>$labelgb</b></td><td class=\"question\"><b>$labelcol</b></td><td class=\"question\"><b>$labelreg</b></td><td align=\"right\" class=\"question\"><b>PRICE</b></td></tr>";
		print '<tr><td class="field"><select name="gearbox">';
		for ($i=0; $i<sizeof($geartypes); $i++) {
			print "<option value=\"$geartypes[$i]\"";
			if ($gearbox==$geartypes[$i]) { print " selected"; }
			print ">$geartypes[$i]</option>";
		}
		print '</select></td><td class="field"><input type="text" name="colour" value="'.$colour.'" size="20" maxlength="30" /></td><td class="field"><input type="text" name="regnumber" value="'.$regnumber.'" size="20" maxlength="20" /></td><td align="right" class="field"><input type="text" name="price" value="'.$price.'" size="12" maxlength="8" onchange="this.value=format_currency(this.value);" style="text-align:right;" /></td></tr>';

		print '<tr><td colspan="4" class="line">&nbsp;</td></tr>';

		print '<tr><td align="right" valign="top" class="question"><b>mileage:</b></td><td valign="top" class="field"><input type="text" name="mileage" value="'.$mileage.'" size="12" maxlength="7" onchange="this.value=format_integer(this.value);" style="text-align:right;" /></td><td colspan="2" class="field">';
		print '<input type="radio" name="mileagekm" value="0" checked />&nbsp;<a href="javascript:selectradio(\'mileagekm\',1)" class="field">miles</a><br />';
		print '<input type="radio" name="mileagekm" value="1" />&nbsp;<a href="javascript:selectradio(\'mileagekm\',2)" class="field">kilometers</a> <i>(will be converted to miles)</i><br />';
		print '</td></tr>';

		print '<tr><td colspan="4" class="line">&nbsp;</td></tr>';

		print '<tr><td colspan="4" class="question"><b>additional information</b> <i>(5000 characters maximum)</i></td></tr>';
		print '<tr><td colspan="4" class="fields"><textarea name="info" rows="20" cols="88" wrap="soft">'.$info.'</textarea></td></tr>';

		// image upload handler
		if (IMAGEUPLOAD) {
		
			print '<tr><td colspan="4" class="line">&nbsp;</td></tr>';
			print '<tr><td colspan="4" class="question"><b>pictures</b> <i>(up to '.$thisSite->maxpics.' JPG pictures can be uploaded)</i><br />';

			// show current set of pictures
			if ($picturelist!="") {

				$pics=explode(',', $picturelist, $thisSite->maxpics);
				$numpics=sizeof($pics);
				if ($numpics>0) {

					print '<table align="center" border="0" cellpadding="2" cellspacing="6"><tr>';
					for ($i=0; $i<$numpics; $i++) {
						print '<td class="thumbnail"><div align="right"><a href="javascript:picdelete('.$i.');" title="delete picture '.($i+1).'"><img src="'.IMAGEFOLDER.'cross.gif" border="0" vspace="2" /></a></div>';
						print "<a href=\"javascript:picpreview($i)\"><img name=\"thumb$i\" src=\"".THUMBFOLDER."$pics[$i].jpg\" width=\"80\" height=\"60\" border=\"0\" alt=\"picture ".($i+1)."\" /></a><br /><div align=\"center\">";
						if ($i>0) { print '<a href="javascript:picswap('.($i-1).','.$i.');" title="move this image"><img src="'.IMAGEFOLDER.'arrowlt.gif" border="0" vspace="2" /></a>&nbsp;'; }
						if ($i<($numpics-1)) { print '&nbsp;<a href="javascript:picswap('.$i.','.($i+1).');" title="move this image"><img src="'.IMAGEFOLDER.'arrowrt.gif" border="0" vspace="2" /></a>'; }
						print '</div>';
						doHidden("pic$i", $pics[$i]);
						print '</td>';
					}
					print '</tr></table><br clear="all" />';
					doHidden('picdelete', '');
				}

			}
			else {
				$numpics=0;
			}

			// list of pictures to delete
			doHidden('picdeleteall', $picdeleteall);
			doHidden('picsadded', $picsadded);

			// show upload boxes
			if ($numpics<$thisSite->maxpics) {
				print '<table align="center" border="0" cellpadding="3" cellspacing="0">';
				for ($i=$numpics+1; $i<=$thisSite->maxpics; $i++) {
					print '<tr><td class="question">JPG '.$i.' <input name="pictures[]" type="file" size="50" /></td></tr>';
				}
				print '<tr><td align="center" class="field"><input type="button" value="upload pictures" onclick="picupload()" class="button" /></td></tr>';
				print '</table>';
			}

			// results of upload operation
			if ($operation=='picupload' && $result!='') print "<br clear=\"all\" /><p class=\"error\"><b>Picture upload report:</b><br />$result</p>";

			print '</td></tr>';
		}
		
		print '<tr><td colspan="4" class="line">&nbsp;</td></tr>';
		print '</table><br clear="all" />';

		print '<div align="center"><input type="button" value="save vehicle" onclick="checkCar()" class="button" />&nbsp;<input type="button" value="cancel" onclick="cancelUpdate()" class="button" /></div>';
		if ($editrecord!=0) print "<div class=\"note\">( Vehicle ID: $editrecord )</div>";

	}

}


// ________________________________________________________
// update or insert a record
function updateRecord() {

	global $db, $thisUser;
	global $editrecord;
	global $display, $new, $year, $make, $model, $type, $regnumber, $mileage, $colour, $gearbox, $info, $price, $picturelist;

	$views=0;
	$enquiries=0;

	// find new record number
	if ($editrecord==0) {
		if ($db->fetch("SELECT MAX(id) FROM ".SITEID.";")) {
			$row=$db->row();
			$editrecord=intval($row[0]+1);
		}
	}
	else {
		if ($db->fetch("SELECT views,enquiries FROM ".SITEID." WHERE id=$editrecord;")) {
			$row=$db->rowassoc();
			$views=intval($row['views']);
			$enquiries=intval($row['enquiries']);
		}
	}

	if ($editrecord!=0) {

		$sql='INSERT INTO '.SITEID.' (id, display, new, year, make, model, type, regnumber, mileage, colour, gearbox, info, price, picturelist, views, enquiries, userupdate, lastupdate) VALUES (';
		$sql.=SQLescape($editrecord).', ';
		$sql.=SQLescape($display).', ';
		$sql.=SQLescape($new).', ';
		$sql.=SQLescape($year == '' ? null : $year).', ';
		$sql.=SQLescape($make).', ';
		$sql.=SQLescape($model).', ';
		$sql.=SQLescape($type).', ';
		$sql.=SQLescape($regnumber).', ';
		$sql.=SQLescape($mileage).', ';
		$sql.=SQLescape($colour).', ';
		$sql.=SQLescape($gearbox).', ';
		$sql.=SQLescape($info).', ';
		$sql.=($price == '' ? 'null' : SQLescape($price)).', ';
		$sql.=SQLescape($picturelist).', ';
		$sql.=SQLescape($views).', ';
		$sql.=SQLescape($enquiries).', ';
		$sql.=SQLescape($thisUser->email).', ';
		$sql.="'".gmdate('YmdHis')."');";

		// delete existing record
		$db->fetch("DELETE FROM ".SITEID." WHERE id=$editrecord;");

		// insert new record
		if ($db->fetch($sql)) {
			$ret="The vehicle has been updated.<br />";
		}
		else {
			$ret="The vehicle could not be saved to the database. Please contact the administrator.<br />";
		}

	}
	else {
		$ret="The vehicle could not be saved to the database. Please contact the administrator.<br />";
	}

	return $ret;
}


// ________________________________________________________
// update or insert a record
function uploadPictures() {

	global $db, $thisSite;
	global $picturelist, $picsadded;

	// get form data
	fetchVehicleForm();

	$ret='';

	// pictures are available
	if (isset($_FILES['pictures']['name'])) {

		for ($i=0; $i<sizeof($_FILES['pictures']['name']); $i++) {

			$file=$_FILES['pictures']['name'][$i];

			// file successfully uploaded
			if ($_FILES['pictures']['error'][$i]==0) {

				$error=false;
				$skipresize=false;

				// check file is a JPG
				$imginfo=@getimagesize($_FILES['pictures']['tmp_name'][$i]);
				if ($imginfo[2]!=2) {
					$ret.="Image '$file' is not a JPG.<br />";
					$error=true;
				}

				// check that image is large enough
				if (!$error && $imginfo[0]<$thisSite->picdimension && $imginfo[1]<$thisSite->picdimension) {
					if ($thisSite->forcedimension) {
						$ret.="Image '$file' is too small. The width or height must be at least ".$thisSite->picdimension." pixels.<br />";
						$error=true;
					}
					else {
						$skipresize=true;
					}
				}

				// check image can be read
				if (!$error) {
					$imgOrig=@imagecreatefromjpeg($_FILES['pictures']['tmp_name'][$i]);
					if (!$imgOrig) {
						$ret.="Image '$file' could not be opened. Please try uploading again.<br />";
						$error=true;
					}
				}

				// fetch image number from database
				if (!$error) {
					$imgNum=$thisSite->nextPic();
					if ($imgNum==0) {
						$ret.="A database error occurred when saving file '$file' (could not update picturenum). Please contact the administrator.<br />";
						$error=true;
					}
				}


				// process image
				if (!$error) {

					if ($picturelist!='') $picturelist.=',';
					$picturelist.=$imgNum;

					if ($picsadded!='') $picsadded.=',';
					$picsadded.=$imgNum;

					// resize original (if necessary)
					if ($skipresize) {
						imagejpeg($imgOrig, PICFOLDER."$imgNum.jpg", 60);
					}
					else {
						$imgNew = sizeFix($imgOrig, $thisSite->picdimension);
						imagejpeg($imgNew, PICFOLDER."$imgNum.jpg", 60);
						imagedestroy($imgNew);
					}

					// create thumbnail
					$imgThumb = sizeExact($imgOrig, $thisSite->thumbdimx, $thisSite->thumbdimy);
					imagejpeg($imgThumb, THUMBFOLDER."$imgNum.jpg", 60);
					imagedestroy($imgThumb);

					$ret.="Image '$file' has been successfully uploaded.<br />";
					imagedestroy($imgOrig);
				}

			}
			else {
				if ($file!='') $ret.="File '$file' could not be uploaded. Please check that the file is a JPG under 1Mb try again.<br />";
			}

		}
	}

	if ($ret=='') {
		$ret='You did not select any pictures to upload.';
	}
	else {
		$ret.="<br />Please click 'save vehicle' to save this set of pictures.";
	}

	return $ret;
}


// ________________________________________________________
// delete picture
function deletePictures($donow=false) {

	global $picdeleteall;

	if ($donow) {

		// delete all pictures
		if ($picdeleteall!='') {

			$pics=explode(',', $picdeleteall);
			for ($i=0; $i<sizeof($pics); $i++) {
				if (!@unlink(PICFOLDER."$pics[$i].jpg")) writeLog(SITELOG, "FAILDEL: could not delete ".PICFOLDER."$pics[$i].jpg\n");
				if (!@unlink(THUMBFOLDER."$pics[$i].jpg")) writeLog(SITELOG, "FAILDEL: could not delete ".THUMBFOLDER."$pics[$i].jpg\n");
			}
		}

	}
	else {

		// store pictures to delete
		$picdelete=intval(postvar('picdelete', 0));
		if ($picdelete!=0) {
			if ($picdeleteall!='') $picdeleteall.=",";
			$picdeleteall.=$picdelete;
		}

	}

}


// ________________________________________________________
// retrieve vehicle data from posted form
function fetchVehicleForm() {
	global $thisSite;
	global $display, $new, $year, $make, $model, $type, $regnumber, $mileage, $colour, $gearbox, $info, $price, $picturelist, $picdeleteall, $picsadded;

	$display=(postvar('display')=='on');
	$new=(postvar('new')=='1');
	$year=postvar('year');
	if (!is_numeric($year)) $year = '';
	else {
		$year = intval($year);
		if ($year > 2100) $year = 2100;
	}
	$make=postvar('make');
	$model=postvar('model');
	$type=postvar('type');
	$regnumber=postvar('regnumber');
	$mileage=postvar('mileage');
	$mileage=preg_replace('/\D/', '', $mileage);
	if (is_numeric($mileage)) { $mileage=intval($mileage); } else { $mileage=0; }

	if (postvar('mileagekm')=='1') {
		// convert km to miles and rounds up to nearest 100
		$mileage*=0.6214;
		$mileage=intval(($mileage / 100)+1) * 100;
	}
	if ($mileage>9999999) $mileage=9999999;

	$gearbox=postvar('gearbox');
	$colour=strtolower(postvar('colour'));
	$price=postvar('price');
	$price=preg_replace('/\D/', '', $price);
	if ($price != '' && is_numeric($price)) {
		$price=intval($price);
		if ($price>999999) $price=999999;
	}
	else $price='';

	$info=trim(postvar('info'));
	if (strlen($info)>5000) $info=truncString($info, 4950, 5000);

	$picturelist='';
	for ($i=0; $i<$thisSite->maxpics; $i++) {
		$thispic=intval(postvar("pic$i", 0));
		if ($thispic>0) {
			if ($picturelist!='') $picturelist.=',';
			$picturelist.=$thispic;
		}
	}

	$picdeleteall=postvar('picdeleteall');
	$picsadded=postvar('picsadded');

}


// ________________________________________________________
// show that user does not have the appropriate permissions
function showPermission($show=false) {
	if ($show) {
		print '<p class="error">You do not have permission to administer vehicles on this site. Please contact your administrator.</p>';
		print '<p>Site ID: '.SITEID.'<br />User ID: '.USERID.'</p>';
	}
}


// ________________________________________________________
// delete non-picture files or unnecessary pictures from folder
function cleanPics($folder="no folder defined", $validpics, $errorlog) {

	if ($dir=opendir($folder)) {
		$fcount=0;
		$fdel=0;
		while (($file=readdir($dir)) !== false) {
			if ($file!="." && $file!=".." && !is_dir($folder.$file)) {

				$fcount++;
				$dodelete=false;

				// is this a JPG?
				if (strpos(strtolower($file), '.jpg') === false) {
					$dodelete=true;
				}
				else {

					// is file in valid picture list?
					$tfile=str_replace('.jpg', '', $file);
					if (strpos($validpics, ",$tfile,") === false) {
						// if an invalid file, is it over a day old?
						if ((time()-filemtime($folder.$file)) > 86400) $dodelete=true;
					}

				}

				// delete the file if required
				if ($dodelete) {
					chmod($folder.$file, 0666);
					if (@unlink($folder.$file)) $fdel++;
					else writeLog($errorlog, "FAILDEL: could not delete $folder$file\n");
				}

			}
		}
		closedir($dir);

		if ($fdel>0) writeLog($errorlog, "$fdel of the $fcount files in the folder $folder have been deleted.\n");
	}
}
?>
